"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var type_1 = require("./type");
/**
 * Kind of primary type
 *
 * @export
 * @enum {number}
 */
var PrimaryTypeKind;
(function (PrimaryTypeKind) {
    PrimaryTypeKind[PrimaryTypeKind["ImplicitAny"] = 0] = "ImplicitAny";
    PrimaryTypeKind[PrimaryTypeKind["PredefinedType"] = 1] = "PredefinedType";
    PrimaryTypeKind[PrimaryTypeKind["TypeReference"] = 2] = "TypeReference";
    PrimaryTypeKind[PrimaryTypeKind["ObjectType"] = 3] = "ObjectType";
    PrimaryTypeKind[PrimaryTypeKind["ArrayType"] = 4] = "ArrayType";
    PrimaryTypeKind[PrimaryTypeKind["TupleType"] = 5] = "TupleType";
    PrimaryTypeKind[PrimaryTypeKind["TypeQuery"] = 6] = "TypeQuery";
    PrimaryTypeKind[PrimaryTypeKind["ThisType"] = 7] = "ThisType";
})(PrimaryTypeKind = exports.PrimaryTypeKind || (exports.PrimaryTypeKind = {}));
/**
 * Primary type specification
 *
 * @export
 * @class PrimaryType
 * @extends {Type}
 */
var PrimaryType = (function (_super) {
    __extends(PrimaryType, _super);
    /**
     * Creates an instance of PrimaryType.
     * @param {string} text Full text for the primary type
     * @param {PrimaryTypeKind} kind Kind of primary type
     *
     * @memberOf PrimaryType
     */
    function PrimaryType(text, kind) {
        var _this = _super.call(this, text) || this;
        _this._kind = kind;
        _this._namespace = null;
        _this._typeArguments = [];
        return _this;
    }
    Object.defineProperty(PrimaryType.prototype, "kind", {
        /**
         * Kind of primary type
         *
         * @type {PrimaryTypeKind}
         * @memberOf PrimaryType
         */
        get: function () {
            return this._kind;
        },
        set: function (value) {
            this._kind = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PrimaryType.prototype, "namespace", {
        /**
         * Namespace of the type reference
         *
         * @type {string}
         * @memberOf PrimaryType
         */
        get: function () {
            return this._namespace;
        },
        set: function (value) {
            this._namespace = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PrimaryType.prototype, "typeArguments", {
        /**
         * Array of type arguments, of a generic type, or a tuple type.
         *
         * Example: A type Dictionary<string,number> would have type arguments [string, number].
         *
         * @type {Type[]}
         * @memberOf PrimaryType
         */
        get: function () {
            return this._typeArguments;
        },
        set: function (value) {
            this._typeArguments = value;
        },
        enumerable: true,
        configurable: true
    });
    return PrimaryType;
}(type_1.Type));
exports.PrimaryType = PrimaryType;
